ListBuilder

Struct ListBuilder 

pub struct ListBuilder { /* private fields */ }
A builder for creating a list request.

Implementations

Source

impl ListBuilder

pub fn with_datasets(self, datasets: Vec<String>) -> Self

Set the datasets for which the annotations are listed.

pub fn with_start(self, start: DateTime<FixedOffset>) -> Result<Self, Error>

Set the start time of the list.

Errors

If the start time is after the end time.

pub fn with_end(self, end: DateTime<FixedOffset>) -> Result<Self, Error>

Set the end time of list.

Errors

If the start time is after the end time.

pub fn build(self) -> List

Builds the request