pub struct Annotation {
pub id: String,
pub annotation_type: String,
pub datasets: Vec<String>,
pub description: Option<String>,
pub title: Option<String>,
pub url: Option<Url>,
pub time: DateTime<FixedOffset>,
pub end_time: Option<DateTime<FixedOffset>>,
}Expand description
An annotation.
Fields
id: StringUnique ID of the annotation
annotation_type: StringType of the event marked by the annotation. Use only alphanumeric characters or hyphens. For example, “production-deployment”.
datasets: Vec<String>Dataset names for which the annotation appears on charts
description: Option<String>Explanation of the event the annotation marks on the charts
title: Option<String>Summary of the annotation that appears on the charts
url: Option<Url>URL relevant for the event marked by the annotation. For example, link to GitHub pull request.
time: DateTime<FixedOffset>Time the annotation marks on the charts. If you don’t include this field, Axiom assigns the time of the API request to the annotation.
end_time: Option<DateTime<FixedOffset>>End time of the annotation